Top_probe: Top Probe Selector

View source: R/generateRef_DEseq2.R

Top_probeR Documentation

Top Probe Selector

Description

Extracts the top 'i' probes based on their ordering in the provided data frame. If the number of rows is less than or equal to 'i', returns all probes.

Usage

Top_probe(dat, i)

Arguments

dat

Data frame containing a column named "probe".

i

Integer. Number of top probes to return.

Value

Character vector containing the names of the top 'i' probes.

Examples

dat <- data.frame(
  probe = c("Probe1", "Probe2", "Probe3", "Probe4", "Probe5"),
  value = c(5, 3, 2, 4, 1)
)
top_probes <- Top_probe(dat, 3)
print(top_probes)

IOBR documentation built on May 30, 2026, 5:07 p.m.