| .appendSignatures | R Documentation |
Calculates mean expression for each marker feature set.
.appendSignatures(xp, markers)
xp |
Expression matrix with features in rows and samples in columns. |
markers |
List of marker gene vectors for each cell population. |
Matrix with summarized expression values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.