View source: R/generateRef_limma.R
| Construct_con | R Documentation |
Creates a contrast matrix for differential analysis, where each phenotype level is contrasted against all other levels combined.
Construct_con(pheno)
pheno |
Factor with different levels representing groups to contrast. |
Square matrix with dimensions equal to the number of levels in 'pheno'. Each row represents a contrast where the corresponding level is compared against the average of others.
pheno <- factor(c("A", "B", "C", "D"))
contrast_matrix <- Construct_con(pheno)
print(contrast_matrix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.