| ConvertRownameToLoci | R Documentation |
Processes a gene expression data matrix by modifying its row names. Extracts the gene identifier from row names formatted as 'GENE|ID', simplifying them to 'GENE'.
ConvertRownameToLoci(cancerGeneExpression)
cancerGeneExpression |
Matrix or data frame. Gene expression data with row names in the format 'GENE|ID'. |
Matrix with modified gene expression data with updated row names. Rows without a valid identifier are removed.
example_data <- matrix(runif(20), ncol = 5)
rownames(example_data) <- c("LOC101", "LOC102", "LOC103", "LOC104")
processed_data <- ConvertRownameToLoci(example_data)
print(processed_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.