View source: R/download_data.R
| add_iobr_mirror | R Documentation |
Adds a custom mirror URL to the default mirrors for the current session. The mirror URL should be a base URL. If it contains 'github.com', it will be treated as a GitHub proxy and the relative path to IOBR releases will be appended. Otherwise, it will be treated as a direct repository path.
add_iobr_mirror(url, position = c("first", "last", "before_github"))
url |
Character string. The mirror URL to add. |
position |
Character. Where to add the mirror: "first", "last", or "before_github". Default: "first". |
Invisibly returns the updated mirror list.
## Not run:
add_iobr_mirror("https://my-mirror.com/https://github.com")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.