| check_cancer_types | R Documentation |
Processes input data containing cancer types and validates each category against a predefined list of supported cancer types ('timer_available_cancers').
check_cancer_types(args)
args |
A list containing input parameters:
|
A character matrix with two columns:
Expression identifiers
Cancer categories
args <- list(
expression = c("exp1", "exp2"),
category = c("luad", "brca"),
batch = NULL
)
result <- check_cancer_types(args)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.