Performs deconvolution of the tumor microenvironment using the TIMER algorithm. Processes multiple cancer datasets, removes batch effects, and estimates immune cell type abundances.
Examples
if (FALSE) { # \dontrun{
# file
tf <- tempfile(fileext = ".csv")
write.table(data.frame("exp1", "luad", "exp2", "brca"),
file = tf, sep = ",", row.names = FALSE, col.names = FALSE, quote = FALSE
)
outdir <- tempdir()
args <- list(outdir = outdir, batch = tf)
results <- deconvolute_timer.default(args)
} # }