View source: R/format_msigdb.R
| format_msigdb | R Documentation |
Reads a GMT file from MSigDB and converts it into a named list of gene sets suitable for IOBR functions.
format_msigdb(gmt, ont = "term", gene = "gene")
gmt |
Character string. Path to a GMT file. |
ont |
Character string. Name of the signature/set column in the parsed GMT table. Default is '"term"'. |
gene |
Character string. Name of the gene column in the parsed GMT table. Default is '"gene"'. |
Named list of character vectors, where each element contains the genes belonging to one signature.
tf <- tempfile(fileext = ".gmt")
writeLines(
c(
"HALLMARK_TNFA_SIGNALING_VIA_NFKB\tNA\tTNF\tNFKB1\tNFKB2",
"HALLMARK_P53_PATHWAY\tNA\tTP53\tMDM2\tCDKN1A"
),
con = tf
)
sig_list <- format_msigdb(tf, ont = "term", gene = "gene")
names(sig_list)
sig_list[[1]]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.