Scales a gene expression matrix, optionally applies logarithmic transformation, and performs feature manipulation to remove problematic variables (e.g., genes with zero variance or missing values).
Examples
eset_gse62254 <- load_data("eset_gse62254")
#> ℹ Trying mirror 1/4: <https://github.com>
#> ✔ Download complete: "eset_gse62254"
eset2 <- scale_matrix(eset_gse62254, log2matrix = FALSE, manipulate = TRUE)
#> ✔ Retained 54675 of 54675 features
#> ℹ Retained 54675 features after manipulation