Sets a custom cache directory for IOBR downloaded data. This is useful when you want to store cached data in a specific location, such as a shared network drive or a custom directory.
Examples
# \donttest{
# Set a custom cache directory (use tempdir() for examples)
set_iobr_cache_dir(tempdir())
#> ✔ IOBR cache directory set to: /tmp/Rtmp5pJcZ0
# Check the current cache directory
get_iobr_cache_dir()
#> [1] "/tmp/Rtmp5pJcZ0"
# Download data will now use the custom cache
data <- download_iobr_data("lm22")
#> ℹ Loading cached data: "lm22"
# }