View source: R/download_data.R
| set_iobr_cache_dir | R Documentation |
Sets a custom cache directory for IOBR downloaded data. This is useful when you want to store cached data in a specific location, such as a shared network drive or a custom directory.
To use the standard system cache location (persistent across sessions), you can use: 'set_iobr_cache_dir(tools::R_user_dir("IOBR", which = "cache"))'.
set_iobr_cache_dir(path, create = TRUE)
path |
Character string. The path to the cache directory. |
create |
Logical. Whether to create the directory if it doesn't exist. Default: TRUE. |
Invisibly returns the cache directory path.
# Set a custom cache directory (use tempdir() for examples)
set_iobr_cache_dir(tempdir())
# Use standard system cache (persistent)
# set_iobr_cache_dir(tools::R_user_dir("IOBR", which = "cache"))
# Check the current cache directory
get_iobr_cache_dir()
# Download data will now use the custom cache
data <- download_iobr_data("lm22")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.