Returns p-values for the null hypothesis that samples are not infiltrated by the corresponding cell population.
Usage
test_for_infiltration(MCPcounterMatrix, platform = c("133P2", "133A", "HG1"))Returns p-values for the null hypothesis that samples are not infiltrated by the corresponding cell population.
test_for_infiltration(MCPcounterMatrix, platform = c("133P2", "133A", "HG1"))