| test_for_infiltration | R Documentation |
Returns p-values for the null hypothesis that samples are not infiltrated by the corresponding cell population.
test_for_infiltration(MCPcounterMatrix, platform = c("133P2", "133A", "HG1"))
MCPcounterMatrix |
Matrix, usually output from MCPcounter.estimate. |
platform |
Expression platform: "133P2", "133A", or "HG1". Default is "133P2". |
Matrix with samples in rows and cell populations in columns. Elements are p-values.
Etienne Becht
# This function requires null_models data which is loaded internally
# Create example data
scores <- matrix(runif(30), nrow = 3, ncol = 10)
rownames(scores) <- c("T cells", "B cells", "NK cells")
pvals <- test_for_infiltration(scores, platform = "133P2")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.