| timer_info | R Documentation |
Formats and displays informational messages for timing or logging purposes. Useful for tracking progress or stages of execution within scripts.
timer_info(string)
string |
Character. Message to be displayed. |
This code is adapted from https://github.com/hanfeisun/TIMER, which again is an adapted version of the original TIMER source code from http://cistrome.org/TIMER/download.html.
The method is described in Li et al. Genome Biology 2016;17(1):174., PMID 27549193. Display Timer Information Messages
None; used for its side effect of printing a message.
Bo Li
timer_info("Data processing started.")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.